package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````,`/@`!````U1X```````!``````````%BQ````
M`````````$``.``)`$``&P`:``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````=`````````!T``````````0`````````!````
M!0```````````````````````````````````-2>````````U)X`````````
M`"````````$````&````<*L```````!PJR```````'"K(```````L`0`````
M``#X"```````````(````````@````8```"(JP```````(BK(```````B*L@
M```````0`@```````!`"````````"``````````$````!````%@"````````
M6`(```````!8`@```````$0`````````1``````````$`````````%#E=&0$
M````V)<```````#8EP```````-B7````````W`````````#<``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````'"K````````<*L@``````!PJR``
M`````)`$````````D`0````````!`````````"]L:6(O;&0M:V9R965B<V0M
M>#@V+38T+G-O+C$`````!````!`````!````1TY5``,````(`````P``````
M```$````%`````,```!'3E4`,[?=/V$"L7+#[P^2+6.K"6?A\X\`````$0``
M`$P````$````"````"`0$``%0`2$*`(``("&`(""*0``"2`$"8B@&$4Z!`((
M`````$P```!0````5````%4```!;````7````%T```!?````8`````````!B
M````8P````````!D``````````````!NQ=\?ZM/O#L[>1RUK?YI\+L6;MB#_
MY`ZXC?$.U634?-EQ6!SB1\8!K$OCP+KCDGS"Y3\L^J%L8+,!BV]K"4/69Z_,
M9D)%U>R)!W#3#13BGMK-XYXS8MOM#3J7"W^IG)NCX/M)````````````````
M````````````````.`,``!(`````````````````````````P`(``!(`````
M````````````````````?`,``!(`````````````````````````(P(``!(`
M````````````````````````$0```"``````````````````````````*@(`
M`!(`````````````````````````G0(``!(`````````````````````````
M<P(``!(`````````````````````````JP(``!(`````````````````````
M````R````!(`````````````````````````G`$``!(`````````````````
M````````;@,``!(`````````````````````````F````!(`````````````
M````````````)0$``!(`````````````````````````N0(``!(`````````
M````````````````CP,``"$`````````````````````````A0(``!(`````
M````````````````````&@$``!$`````````````````````````@`$``!(`
M````````````````````````_````!$`````````````````````````/P,`
M`!(`````````````````````````3@$``!(`````````````````````````
MU@```!(`````````````````````````R@$``!(`````````````````````
M````:P(``!(`````````````````````````5`(``!(`````````````````
M````````MP$``!(`````````````````````````D`,``!$`````````````
M````````````"0(``!(`````````````````````````"@,``!(`````````
M````````````````]P(``!(`````````````````````````7`$``!(`````
M````````````````````*P,``!(`````````````````````````?`(``!(`
M````````````````````````'0(``!(`````````````````````````+0``
M`"```````````````````````````@,``!(`````````````````````````
MX@(``!(`````````````````````````U0$``!$`````````````````````
M````>````!(`````````````````````````QP(``!(`````````````````
M````````20,``"(`````````````````````````=0,``!(`````````````
M````````````C@,``!$`````````````````````````[`,``!(`````````
M````````````````IP```!(`````````````````````````LP```!(`````
M````````````````````0P(``!(`````````````````````````=0$``!(`
M````````````````````````.P$``!(`````````````````````````&P,`
M`!(`````````````````````````:@```!(`````````````````````````
M9@,``!(`````````````````````````*@$``!(`````````````````````
M````+P$``!(`````````````````````````Z0(``!(`````````````````
M````````K`$``!(`````````````````````````"0$``!(`````````````
M````````````S@(``!(`````````````````````````C@$``!(`````````
M````````````````AP```!(`````````````````````````E@(``!(`````
M````````````````````HP(``!(`````````````````````````/````"``
M````````````````````````[0```!(`````````````````````````;`$`
M`!(`````````````````````````%`,``!$`````````````````````````
ML@(``!(`````````````````````````(@,``!(`````````````````````
M````.P(``!(`````````````````````````U`(``!(`````````````````
M````````4````"``````````````````````````PP$``!(`````````````
M````````````9@(``!(`````````````````````````6`,``!(`````````
M````````````````]0,``!(`#0``5@```````'8`````````PP,``!(`#@`4
M5P``````````````````&@0``!(`#0``1@```````#0,````````B0,``!(`
M#0"0'````````$4"````````R0,``!(`#0"`/@````````,`````````<@0`
M`!(`#0"0/@````````P"````````;`0``!(`"@!X&@``````````````````
MGP0``!(`#0!`4@```````+4#````````K0,``!``&``@L"``````````````
M`````00``!(`#0"@0````````"0`````````-`0``!$`#P`@5P````````0`
M````````Z````!``&`!HM"``````````````````:@0``!(`#0#P/0``````
M`#,`````````?P0``!(`#0"01````````&P!````````D00``!(`#0#@0P``
M`````'D`````````)P0``!``%P``L"``````````````````#@0``!(`#0#0
M0````````.,`````````I@,``!``%P`@L"``````````````````4P0``!$`
M%P`8L"````````@`````````N0,``!(`#0`05P````````(`````````0P0`
M`!(`#0"@5@```````&4`````````+00``!(`#0#5'@``````````````````
M*00``"``%P``L"``````````````````V@,``!(`#0!@1````````"0`````
M````700``!(`#0#`00```````!("`````````&QI8G!E<FPN<V\N-2XR-`!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV
M7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E
M<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P
M97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]E;F0`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR
M7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO
M861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C
M`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXQ`&QI8G!T:')E
M860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R
M<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C`N,0!?7W)E9VES
M=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S
M=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T
M<&ED`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`
M;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T
M870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C
M:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?7VQI8F-?8W-U
M7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R
M7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!?7VQI8F-?
M8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F
M:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C,`1TQ)0D-?,BXQ-`!'3$E"0U\R
M+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0````"``(``@`#`````P`"``(`
M`@```````@```````@`"``0``````````@`````````"``4````"``,``@`"
M````!@`"``,````"``<```````(``@`"``(``@```````P```````@````(`
M`@````8```````(```````(``@`````````"``(``@`#``8````"``(`!@`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!`````0`!`/D!```0````(````!-I:0T```,`M00````````!``4`2`(`
M`!``````````E)&6!@``!P"_!```$````'09:0D```8`R@0``!````!R&6D)
M```%`-8$```0````%&EI#0``!`#B!```$````!-I:0T```(`M00```````!P
MJR````````@`````````X!\```````!XJR````````@`````````H!\`````
M```XKR````````@`````````:+0@```````(L"````````@`````````"+`@
M```````8L"````````@`````````6%H```````"PK2````````8````!````
M``````````"XK2````````8````"``````````````#`K2````````8````#
M``````````````#(K2````````8````$``````````````#0K2````````8`
M```%``````````````#8K2````````8````&``````````````#@K2``````
M``8````'``````````````#HK2````````8````(``````````````#PK2``
M``````8````)``````````````#XK2````````8````*````````````````
MKB````````8````+```````````````(KB````````8````,````````````
M```0KB````````8````-```````````````8KB````````8````.````````
M```````@KB````````8````/```````````````HKB````````8````1````
M```````````PKB````````8````2```````````````XKB````````8````3
M``````````````!`KB````````8````4``````````````!(KB````````8`
M```5``````````````!0KB````````8````6``````````````!8KB``````
M``8````7``````````````!@KB````````8````8``````````````!HKB``
M``````8````9``````````````!PKB````````8````:``````````````!X
MKB````````8````;``````````````"`KB````````8````<````````````
M``"(KB````````8````=``````````````"0KB````````8````>````````
M``````"8KB````````8````?``````````````"@KB````````8````@````
M``````````"HKB````````8````A``````````````"PKB````````8````B
M``````````````"XKB````````8````C``````````````#`KB````````8`
M```D``````````````#(KB````````8````E``````````````#0KB``````
M``8````F``````````````#8KB````````8````G``````````````#@KB``
M``````8````H``````````````#HKB````````8````I``````````````#P
MKB````````8````J``````````````#XKB````````8````K````````````
M````KR````````8````M```````````````(KR````````8````N````````
M```````0KR````````8````O```````````````8KR````````8````P````
M```````````@KR````````8````Q```````````````HKR````````8````R
M```````````````PKR````````8````S``````````````!`KR````````8`
M```T``````````````!(KR````````8````U``````````````!0KR``````
M``8````V``````````````!8KR````````8````W``````````````!@KR``
M``````8````X``````````````!HKR````````8````Y``````````````!P
MKR````````8````Z``````````````!XKR````````8````[````````````
M``"`KR````````8````\``````````````"(KR````````8````]````````
M``````"0KR````````8````^``````````````"8KR````````8````_````
M``````````"@KR````````8```!```````````````"HKR````````8```!!
M``````````````"PKR````````8```!"``````````````"XKR````````8`
M``!#``````````````#`KR````````8```!$``````````````#(KR``````
M``8```!%``````````````#0KR````````8```!&``````````````#8KR``
M``````8```!'``````````````#@KR````````8```!(``````````````#H
MKR````````8```!)``````````````#PKR````````8```!*````````````
M``#XKR````````8```!+``````````````!(@^P(2(L%/90@`$B%P'0"_]!(
M@\0(PP#_-0J3(`#_)0R3(``/'T``_R4*DR``9I#_)0J3(`!FD/\E"I,@`&:0
M_R4*DR``9I#_)1*3(`!FD/\E$I,@`&:0_R42DR``9I#_)1*3(`!FD/\E$I,@
M`&:0_R4:DR``9I#_)1J3(`!FD/\E&I,@`&:0_R4:DR``9I#_)1J3(`!FD/\E
M(I,@`&:0_R4JDR``9I#_)2J3(`!FD/\E*I,@`&:0_R4JDR``9I#_)2J3(`!F
MD/\E*I,@`&:0_R4JDR``9I#_)3*3(`!FD/\E,I,@`&:0_R4RDR``9I#_)3*3
M(`!FD/\E,I,@`&:0_R4RDR``9I#_)3*3(`!FD/\E.I,@`&:0_R4ZDR``9I#_
M)4*3(`!FD/\E0I,@`&:0_R5"DR``9I#_)4*3(`!FD/\E0I,@`&:0_R5"DR``
M9I#_)4*3(`!FD/\E0I,@`&:0_R5"DR``9I#_)4J3(`!FD/\E4I,@`&:0_R52
MDR``9I#_)5*3(`!FD/\E4I,@`&:0_R52DR``9I#_)5*3(`!FD/\E4I,@`&:0
M_R52DR``9I#_)5*3(`!FD/\E6I,@`&:0_R5:DR``9I#_)6*3(`!FD/\E8I,@
M`&:0_R5JDR``9I#_)6J3(`!FD/\E:I,@`&:0_R5JDR``9I#_)7*3(`!FD/\E
M<I,@`&:0_R5RDR``9I```````````%532(/L.(E\)!Q(B70D$$B-?"0<2(E4
M)`A(C70D$$B-5"0(9$B+!"4H````2(E$)"@QP.C0_O__2(LU69(@`$B+/;*2
M(`!(B?+HHCD``$B+!5N1(`"`.``/A#\!``!(BQT[D2``BSOH5/[__X"((@0`
M``*+.^A&_O__@(@B!````8M$)!R->`5(N/________\?2&/_2#G'#X=?`0``
M2,'G`TB-'=4[``#H"O[__TB+?"002(D%_I8@`+X%````QP7WEB``!````$B+
M%TB)6`A(C1VJ.P``2(/'"$B)6!A(B1!(BQ6?DB``2(E0$(M4)!R#^@&-2@1^
M'0\?@`````!,BP],8\:#Q@%(@\<(.<Y.B4S`^'7J2(L]LY8@`$ACR4B--7D@
M``!(QT3(^`````"#P@-%,<!(B<'H0O[__X7`B<,/A(P```!(BSV!EB``2(UL
M)"3H)_W__TB-/<<Y```QP$B)[NAF&0``2(7`='A(BSU:EB``Z.W\___HV/W_
M_XG82(M<)"AD2#,<)2@````/A:````!(@\0X6UW#Z/[\__](A<!(B04DEB``
M#X2)````2(G'Z*;\__](BQW?CR``BSOH^/S__\:`)0@```#ID?[__TB+/?65
M(`#HV/W__XG#Z6'___](BSW:E2``2(7_=!_H>#<``.ER____2(LU1)`@`$B-
M/8PX```QP.@F_?__2(T]PS@``$B)[NBO&```2(7`2(G'2(D%FI4@``^$.___
M_^N]Z#W\__^_`0```.BC_?__,>U)B?%(BS=(C5<(2(/D\%!43(T%(C@``$B-
M#:LW``!(C3V4_?__Z*_[___T2(L%+Y`@``\?@`````!(C3T)D2``2(T%"9$@
M`%5(*?A(B>5(@_@.=A5(BP6>CB``2(7`=`E=_^!F#Q]$``!=PP\?0`!F+@\?
MA```````2(T]R9`@`$B--<*0(`!52"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT
M&$B+!6&0(`!(A<!T#%W_X&8/'X0``````%W##Q]``&8N#Q^$``````"`/7F0
M(```=2=(@ST_CR```%5(B>5T#$B+/4J0(`#HY?O__^A(____7<8%4)`@``'S
MPP\?0`!F+@\?A```````2(T]F8L@`$B#/P!U"^E>____9@\?1```2(L%H8\@
M`$B%P'3I54B)Y?_07>E`____05=!5DR-3SA!54%4,<E54TB![)@"``!D2(L$
M)2@```!(B80DB`(``#'`2(GB#Q\`08L$"4V+!`D/R$R)QHG`2,'N($B)!$I,
MB<!)P>@X2,'H*"4`_P``3`G`28GP2,'F"$G!X!B!Y@``_P!%B<!,"<!("?!(
MB41*"$B#P0A(@_E`=:U(C;(``@``9@\?1```2(M":$@S0D!(@\((2#-""$@S
M0OA(C0P`2,'H'T@)R(/@_TB)0GA(.?)UU4R+!TR+7R!,BT\03(M7&$B+=PA(
MBTPD"$R)P$R)PDV)Q4C!ZAM(P>`%2<'M`D@)T$B+%"1(B?.)P$C!XQY)C8P*
MF7F"6DF-E!.9>8):2`'03(G*3#'22"'R3#'22`'"2(GP2,'H`D&)U$@)PTR)
MR$R)Y8G;2,'M&T@QV$PAP$PQR$@!R$R)X4C!X05(">F)R4@!R$R)P4C!X1Z)
MQ4P)Z4V)Y4F)[HG)2??52<'N&TDAW4@ARDP)ZDR+;"003XVL*9EY@EI,`>I)
MB>U)P>4%30GU18GM3`'J38GE2<'L`DG!Y1Y!B=9-">Q%B>5)B>Q)]]1,(>A)
M(<Q,">!,BV0D&$J-G".9>8):38GT2<'L&T@!V$R)\TC!XP5,">.)VT@!V$B)
MZTC![0)(P>,>08G$2`G=B>M,B?5(]]5((=I,(>U(">I(BVPD($B-C"F9>8):
M3(GE2,'M&T@!RDR)X4C!X05(">F)R4@!RDR)\4G![@)(P>$>B=5)"<Y$B?%-
MB>9)]]9((<A)(=Y,"?!,BW0D*$^-K#69>8):28GN2<'N&TP!Z$F)[4G!Y05-
M"?5%B>U,`>A-B>5)P>4>2<'L`D&)QDT)[$6)Y4F)[$GWU$PAZDDAS$P)XDR+
M9"0P2HV<(YEY@EI-B?1)P>P;2`':3(GS2,'C!4P)XXG;2`':2(GK2,'M`DC!
MXQY!B=1("=V)ZTR)]4CWU4@AV$PA[4@)Z$B+;"0X2(V,*9EY@EI,B>5(P>T;
M2`'(3(GA2,'A!4@)Z8G)2`'(3(GQ2<'N`DC!X1Z)Q4D)SD2)\4V)YDGWUD@A
MRDDAWDP)\DR+="1`3XVL-9EY@EI)B>Y)P>X;3`'J28GM2<'E!4T)]46)[4P!
MZDV)Y4G!Y1Y)P>P"08G630GL18GE28GL2??43"'H22',3`G@3(MD)$A*C9PC
MF7F"6DV)]$G![!M(`=A,B?-(P>,%3`GCB=M(`=A(B>M(P>T"2,'C'D&)Q$@)
MW8GK3(GU2/?52"':3"'M2`GJ2(ML)%!(C8PIF7F"6DR)Y4C![1M(`<I,B>%(
MP>$%2`GIB<E(`<I,B?%)P>X"2,'A'HG520G.1(GQ38GF2??62"'(22'>3`GP
M3(MT)%A/C:PUF7F"6DF)[DG![AM,`>A)B>U)P>4%30GU18GM3`'H38GE2<'L
M`DG!Y1Y!B<9-">Q%B>5)B>Q)]]1,(>I)(<Q,">),BV0D8$J-G".9>8):38GT
M2<'L&T@!VDR)\TC!XP5,">.)VT@!VDB)ZTC![0)(P>,>08G42`G=B>M,B?5(
M]]5((=A,(>U(">A(BVPD:$B-C"F9>8):3(GE2,'M&T@!R$R)X4C!X05(">E,
MB?5)P>X"2,'E'HG)20GN2`'(1(GU38GFB<%)]]9((>I)(=Y,"?),BW0D<$^-
MK#69>8):28G.2<'N&TP!ZDF)S4G!Y05-"?5%B>U,`>I-B>5)P>P"2<'E'D&)
MUTT)[$6)Y4F)S$GWU$PAZ$DA[$P)X$R+9"1X2HV<(YEY@EI-B?Q)P>P;2`'8
M3(G[2,'C!4P)XXG;2`'82(G+2,'I`DC!XQY!B<1("=F)RTR)^4CWT4@AVDPA
MZ4@)RDB+C"2`````2(V,#9EY@EI,B>5(P>T;2`'13(GB2,'B!4@)ZDR)_4G!
M[P)(P>4>B=)(`=%)">],B>)$B?U(]])!B<Y((=I((>A("=!(BY0DB````$F-
ME!69>8):38GU2`'03(GR2,'B!4G![1M,">I-B>5)P>P"2<'E'HG230GL2`'0
M2(N4))````!%B>5-B?1!B<=)]]1,(>E)(>Q,">%,C:03F7F"6DR)^DC!X@5)
M`<Q,B?E(P>D;2`G*B=))`=1,B?))P>X"2,'B'D2)XTP)\DV)_HG12??632'N
M2"'(3`GP3(NT))@```!*C:PUF7F"6DF)WDG![AM(`>A(B=U(P>4%3`GUB>U(
M`>A,B?U)P>\"2,'E'D&)QDP)_4@QZD$QU$B+E"2@````28V4%:'KV6Y-B?5,
M`>)-B?1)P>0%2<'M&TT)[$6)Y$P!XDF)W$C!ZP))P>0>08G520G<2(GKB>U,
M,>-(`ZPDL````#'82(N<)*@```!(C9P9H>O9;DR)Z4C!Z1M(`<-,B>A(P>`%
M2`G(B<!(`<-,B?!)P>X"2,'@'HG93`GP38GF18GD23'&3`.D)+@```!$,?),
MC;P5H>O9;DB)RDB)S4C![1M(P>(%2`GJ3(GM2<'M`DC!Y1Z)TDP)[4F)Q4D!
MUTDQ[42)^HG`1#'K38VL'*'KV6Y(B=-)B=1)P>P;2,'C!4P)XXG;20'=2(G+
M2`.$),````!(P>D"2,'C'D6)[D@)RTB)Z4V)]$@QV4G![!M!,<]*C8PXH>O9
M;DR)\$C!X`5,">")P$@!R$B)T4C!Z@)(P>$>08G$2`G1B>I(`Y0DR````$B)
MW8G;2`.<)-````!(,<U!,>U*C:PJH>O9;DR)XDV)Y4G![1M(P>(%3`GJB=)(
M`=5,B?))P>X"2,'B'D&)[4P)\DF)SHG)23'61#'P38GN2(V<`Z'KV6Y,B>A)
MP>X;2,'@!4P)\(G`2`'#3(G@2,'@'DG![`)(`XPDV````$P)X$F)U$&)WDDQ
MQ(G22`.4).````!$,>5-B?1(C:PIH>O9;DR)\4G![!M(P>$%3`GAB<E(`>E,
MB>U)P>T"2,'E'D&)S$P)[4F)Q8G`23'M2`.$).@```!$,>M-B>5(C9P:H>O9
M;DR)XDG![1M(P>(%3`GJB=)(`=I,B?-)P>X"2,'C'D&)U4P)\TF)[HGM23'>
M1#'Q38GN2(V,"*'KV6Y,B>A)P>X;2,'@!4P)\(G`2`'(3(GA2<'L`DC!X1Y!
MB<9,">%(`ZPD\````$F)W$DQS(G;2`.<)/@```!$,>)-B?1)P>P;2(VL%:'K
MV6Y,B?)(P>(%3`GBB=)(`=5,B>I)P>T"2,'B'D&)[$P)ZDF)S8G)23'52`.,
M)``!``!$,>A-B>5(C9P#H>O9;DR)X$G![1M(P>`%3`GHB<!(`<-,B?!)P>X"
M2,'@'D&)W4P)\$F)UHG223'&2`.4)`@!``!$,?5-B>Y(C:PIH>O9;DR)Z4G!
M[AM(P>$%3`GQB<E(`>E,B>5)P>P"2,'E'D&)SDP)Y4F)Q(G`23'L1#'C38GT
M2`.$)!`!``!(C9P:H>O9;DR)\DG![!M(P>(%3`GBB=)(`=I,B>M)P>T"2,'C
M'D&)U$P)ZTF)[8GM23'=2`.L)!@!``!$,>E-B>5(C8P(H>O9;DR)X$G![1M(
MP>`%3`GHB<!(`<A,B?%)P>X"2,'A'D&)Q4P)\4F)WHG;23'.2`.<)"`!``!$
M,?),C;05H>O9;DR)ZDR)[4C![1M(P>(%2`GJB=))`=9,B>))P>P"2,'B'D2)
M]4P)XDF)S(G)23'41#'@28GL2(V<`Z'KV6Y(B>A(P>`%2<'L&T@#C"0H`0``
M3`G@B<!(`<-,B>A)P>T"2,'@'D&)W$P)Z$F)U8G223'%2`.4)#`!``!%,>Y.
MC:PQH>O9;DR)X4V)YDG![AM(P>$%3`GQB<E)`<U(B>E(P>T"2,'A'D6)[T@)
MZ4B)Q8G`2#'-2`.$)#@!```QZTR)_4B-G!JAZ]EN3(GZ2,'M&TC!X@5(">I,
MB>5)P>P"2,'E'HG23`GE28G,2`':23'LB=.)R44QY4F)W$Z-M"BAZ]EN2(G8
M2<'L&TC!X`5,">!-B?R)P$D!QDG![P))P>0>30G\2(GH18GU3`G@2"'"2(GH
MB>U,(>`)PKC<O!N/28G'3`.\)$`!``!,`?E-B>](`<I,B>E)P>\;2,'A!4P)
M^8G)2`'*2(G92,'K`DC!X1Y!B==("=E,B>-("<M)(=Y,B>-%B>1((<M!"=Y(
MB<-(`YPD2`$``$@!W4R)^TD![DR)_4C!XP5(P>T;2`GKB=M)C2P>3(GK2<'M
M`DC!XQY,">M)B<U!B>Y)"=U,(>I)B<V)R4DAW40)ZDF)Q4P#K"10`0``30'L
M38GU20'43(GR2<'M&TC!X@5,">J)TDV-+!1,B?I)P>\"2,'B'DP)^DF)WT6)
M[$D)UTPA_4F)WXG;22'71`G]28G'3`.\)%@!``!,`?E-B>=(`<U,B>%)P>\;
M2,'A!4P)^8G)3(U\#0!,B?%)P>X"2,'A'DP)\4F)UD2)_4D)SDTA]4F)UHG2
M22'.10GU28G&3`.T)&`!``!,`?--C70=`$B)ZTF)[4C!XP5)P>T;3`GKB=M-
MC2P>3(GC2<'L`DC!XQY)"=Q(B<M%B>Y,">-)(=](B<N)R4PAXT$)WTB)PT@#
MG"1H`0``2`':3(GS20'73(GR2,'K&TC!X@5("=J)TDF-'!=(B>I(P>T"2,'B
M'D@)U4R)XD&)WT@)ZDDAU4R)XD6)Y$@AZD$)U4B)PD@#E"1P`0``2`'13(GZ
M3`'I38G]2,'B!4G![1M,">J)TDR-+!%,B?))P>X"2,'B'DP)\DF)[D2)Z4D)
MUDPA\TF)[HGM22'61`GS28G&3`.T)'@!``!-`?1)B<Y)`=Q(B<M)P>X;2,'C
M!4P)\XG;38TT'$R)^TG![P)(P>,>3`G[28G718GT20G?32']28G7B=))(=]%
M"?U)B<=,`[PD@`$``$P!_4V-?"T`3(GE38GE2<'M&TC!Y05,">V)[4V-+"](
MB<U(P>D"2,'E'D@)Z4B)W46)[T@)S4DA[DB)W8G;2"'-00GN2(G%2`.L)(@!
M``!(`>I,B?U)`=9,B?I(P>(%2,'M&T@)ZHG228TL%DR)XDG![`)(P>(>20G4
M2(G*08GN3`GB22'52(G*B<E,(>)!"=5(B<)(`Y0DD`$``$@!TTR)\DP!ZTV)
M]4C!X@5)P>T;3`GJB=),C2P33(GZ2<'O`DC!XAY,"?I-B>=$B>M)"==,(?U-
MB>=%B>1)(==$"?U)B<=,`[PDF`$``$P!^4F)WT@!S4B)V4G![QM(P>$%3`GY
MB<E,C7P-`$R)]4G![@)(P>4>3`GU28G61(GY20GN32'U28G6B=))(>Y%"?5)
MB<9,`[0DH`$``$T!]$F)SDT!Y4F)S$G![AM)P>0%30GT18GD3XUT)0!)B=Q(
MP>L"2<'D'DP)XTF)[$6)]4D)W$TAYTF)[(GM22'<10GG28G$3`.D)*@!``!,
M`>)-B>Q)`==,B>I)P>P;2,'B!4P)XHG238TD%TB)RDC!Z0)(P>(>2`G12(G:
M18GG2`G*22'62(G:B=M((<I!"=9(B<)(`Y0DL`$``$@!U4R)^DD![DR)_4C!
MX@5(P>T;2`GJB=))C2P63(GJ2<'M`DC!XAY,">I)B<U!B>Y)"=5-(>Q)B<V)
MR4DAU44)[$F)Q4P#K"2X`0``3`'K38GU20'<3(GS2<'M&TC!XP5,">N)VTP!
MXTV)_$G![P))P>0>08G=30G\28G730GG3"']28G7B=)-(>=$"?U)B<=,`[PD
MP`$``$P!^4R-?`T`3(GI3(GM2,'M&TC!X05(">F)R4F-+`],B?%)P>X"2,'A
M'DD)SDR)X4&)[TP)\4@ARTR)X46)Y$PA\0G+2(G!2`.,),@!``!(`<I(C0P3
M3(GZ3(G[2,'K&TC!X@5("=J)TDB-'!%,B>E)P>T"2,'A'DP)Z4V)]8G:20G-
M3"'M38GU18GV22'-1`GM28G%3`.L)-`!``!(`X0DV`$``$T![$Z-;"4`2(G5
M28G42<'L&TC!Y05,`?!,">6)[4V-9"T`3(G]2<'O`DC!Y1Y,"?U)B<]%B>5)
M">]-B>Y,(?M)B<^)R4DA[T0)^T@!V$R)ZTC!XP5)P>X;3`GSB=M(`=A(B=-(
MP>H"2,'C'D&)QD@)T[K6P6+*28G73`.\).`!``!)`<](B>F)[4@QV4$QS$N-
M#"=-B?1-B?=)P>\;2<'D!4T)_$6)Y$P!X4V)[$G![0))P>0>08G/30GL28G5
M3`.L).@!``!,`>U)B=V)VTTQY40QZ$V)_4@!Z$R)_4G![1M(P>4%3`GMB>U(
M`>A,B?5)P>X"2,'E'D&)Q4P)]4F)UDP#M"3P`0``3`'S38GF18GD23'N1#'Q
M38GN2`'93(GK2<'N&TC!XP5,"?.)VT@!V4R)^TG![P)(P>,>08G.3`G[28G7
M3`.\)/@!``!-`?Q)B>^)[4DQWT0Q^$V)]TP!X$V)]$G![QM)P>0%30G\18GD
M3`'@38GL2<'M`DG!Y!Y!B<=-">Q)B=5,`ZPD``(``$P![4F)W8G;33'E1#'I
M38G]2`'I3(G]2<'M&TC!Y05,">V)[4@!Z4R)]4G![@)(P>4>08G-3`GU28G6
M3`.T)`@"``!,`?--B>9%B>1),>Y$,?!-B>Y(`=A,B>M)P>X;2,'C!4P)\XG;
M2`'83(G[2<'O`DC!XQY!B<9,"?M)B==,`[PD$`(``$T!_$F)[XGM23'?1#'Y
M38GW3`'A38GT2<'O&TG!Y`5-"?Q%B>1,`>%-B>Q)P>T"2<'D'D&)STT)[$F)
MU4P#K"08`@``3`'M28G=B=M-,>5$,>A-B?U(`>A,B?U)P>T;2,'E!4P)[8GM
M2`'H3(GU2<'N`DC!Y1Y!B<5,"?5)B=9,`[0D(`(``$P!\TV)YD6)Y$DQ[D0Q
M\4V)[D@!V4R)ZTG![AM(P>,%3`GSB=M(`=E,B?M)P>\"2,'C'D&)SDP)^TF)
MUTP#O"0H`@``30'\28GOB>U),=]$,?A-B?=,`>!-B?1)P>\;2<'D!4T)_$6)
MY$P!X$V)[$G![0))P>0>08G'30GL28G53`.L)#`"``!,`>U)B=V)VTTQY40Q
MZ4V)_4@!Z4R)_4G![1M(P>4%3`GMB>U(`>E,B?5)P>X"2,'E'D&)S4P)]4F)
MUDP#M"0X`@``3`'S38GF18GD23'N1#'P38GN2`'83(GK2<'N&TC!XP5,"?.)
MVT@!V$R)^TG![P)(P>,>08G&3`G[28G73`.\)$`"``!-`?Q)B>^)[4DQWT0Q
M^4V)]TP!X4V)]$G![QM)P>0%30G\18GD3`'A38GL2<'M`DG!Y!Y!B<]-">Q)
MB=5,`ZPD2`(``$P![4F)W8G;33'E1#'H38G]2`'H3(G]2<'M&TC!Y05,">V)
M[4@!Z$R)]4G![@)(P>4>08G%3`GU28G63`.T)%`"``!,`?--B>9%B>1),>Y$
M,?%-B>Y(`=E,B>M)P>X;2,'C!4P)\XG;2`'93(G[2<'O`DC!XQY!B<Y,"?M)
MB==,`[PD6`(``$T!_$F)[XGM23'?1#'X38GW3`'@38GT2<'O&TG!Y`5-"?Q%
MB>1,`>!-B>Q)P>T"2<'D'D&)QTT)[$F)U4P#K"1@`@``3`'M28G=B=M-,>5$
M,>E-B?U(`>E,B?U)P>T;2,'E!4P)[4V)]4G![@))P>4>B>U-"?5)B=9,`[0D
M:`(``$@!Z8G-3`'S38GF18GD33'N1#'P28GN2`'82(GK2<'N&TC!XP5,"?.)
MVT@!V$R)^TG![P)(P>,>08G&3`G[28G73`.\)'`"``!-`?Q-B>]%B>U),=]$
M,?E-B?=(`Y0D>`(``$D!S$R)\4G![QM(P>$%00';3`GY3(E?($$!S$B)Z4C!
M[0)(P>$>3`'J28G=2`GI3(GU2<'N`DDQS4C!Y1Y$`>9$,>A-B>5,"?5(`=!,
MB>))P>T;2,'B!4$!Z40!T4P)ZDB)=PA,B4\0`=!(B4\800'`2(N$)(@"``!D
M2#,$)2@```!,B0=U$DB!Q)@"``!;74%<05U!7D%?P^BRX___9BX/'X0`````
M`$%7059!54%455-(@^P(2(7_#X2C````2(L%`G<@`$R+.$V%_P^$D`````^V
M!X3`=&\\/71K28G\28/$`4$/M@0DA,!T!#P]=>]!*?Q)BQ](A=MT,DF)]4F)
M_DUCY$R)_4R)XDR)]DB)W^AJX___A<!U!T*`/",]="](@\4(2(M=`$B%VW7:
M2(/$"$B)V%M=05Q!74%>05_##Q^$``````!%,>3KIP\?`$PI_4J-7",!2,']
M`T&);0#KS#';Z\AFD%532(G]2(/L&&1(BP0E*````$B)1"0(,<!(C5PD!&:0
M,<!(B=Y(B>_H$____TB%P'0X2(L%)W8@`$AC5"0$2(L`2(T$T$B+4`A(A=)(
MB1!TSP\?@`````!(@\`(2(M0"$B%TDB)$'7PZ[9(BT0D"&1(,P0E*````'4'
M2(/$&%M=P^ABXO__9BX/'X0``````$%7059!54%455-(B?-(B?U(@^PH9$B+
M!"4H````2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z,'A__](C70D%$F)Q$B)[S'`
MZ&?^__](A<`/A`X!``!(B<=)B<7HF^'__TDYQ`^&V@```$AC3"043(LM7G4@
M`$C!X0,/MD4`A,`/A*D!```\/0^$H0$``$B)Z.L&D(#Z/70+2(/``0^V$(32
M=?!(*>A(F$D#30!*C7P@`DF)SN@*X___2(7`28D&#X1]`0``2&-4)!1)BT4`
M2(U-`4B+%-`/MD4`/#V(`G0AA,!U"^L;#Q]$```\/7022(/!`0^V0?](@\(!
MA,"(`G7JQ@(],<`/'T0```^V#`.(3`(!2(/``83)=?`QP$B+="089$@S-"4H
M````#X4;`0``2(/$*%M=05Q!74%>05_##Q\`2(/#`0^V0_])@\4!A,!!B$7_
M=>SKPF8N#Q^$``````!,BRUI="``38M]`$F#/P`/A+T```!,B?@QTNL'#Q]`
M`$2)\DB#P`A$C7(!2(,X`'7OC7(#2&/V2,'F`XL%[WD@`(7`=#M,B?_HV^'_
M_TB%P$F)10`/A(4```!-8\Y)B<!*C0S-`````$O'1,@(`````$2)="04Z9O^
M__\/'T0``$B)]\<%HWD@``$```#HSN'__TB%P'1(36/.3(G^2(G'2HT,S0``
M``!,B4PD"$B)RDB)#"3H)^'__TR+3"0(28G`28E%`$B+#"3KG3'`Z7/^__^^
M$````$4Q]NE<____N/_____IT?[__^@*X/__9I!!5D%505154TB![)````!D
M2(L$)2@```!(B80DB````#'`2(7_=`B`/P!(B?UU,4B+A"2(````9$@S!"4H
M````#X4Q`0``2('$D````%M=05Q!74%>PV8N#Q^$``````#H(^#__TB%P$F)
MQ'3"28GE3(GGZ*#?__](A<!(B<-T-0^V4PBX+@```(G!*=%U00^V4PF%TG39
M*=`/A,$```#WV(7`=2],B>?H:]___TB%P$B)PW7+3(GGZ+O?__](B>_H6^#_
M_^EE____9@\?1```A<ETG$B#PPA(B>_HR-[__TB)WTF)QNB]WO__08U\!@)(
M8__H>.#__TB-#24;``!)B<9(B<=)B=E)B>A(Q\+_____O@$````QP.ABX/__
MOP,```!,B>I,B?;H*M___X/X_TR)]W0/#[=$)!!F)0#P9CT`0'0KZ.;?__],
MB??HIM___^D9____9@\?A```````#[9#"NDX____#Q^``````.B+_O__Z]/H
MC-[__P\?0`!54TB)_4B#[`A(BQV@<2``BSOHN=[__TB-D/@!``!(B>Z_`P``
M`.BUWO__A<!T$4B#Q`@QP%M=PP\?A```````BSOHB=[__P^W@`@"``!F)0#P
M9CT`0'08BSOH<=[__P^W@`@"``!F)0#P9CT`H'6_2(GOO@(```#HZ]W__X7`
M#Y3`2(/$"`^VP%M=PP\?0`!!54%428G\55-(C3T*&@``28GUNO\#``!(@>P8
M!```2(GF9$B+!"4H````2(F$)`@$```QP.@.W___A<!^<HU0_TB)XTACZH`\
M+`!T6TACZ$B)ZKXO````2(G?Z&C=__](A<!T2TB+!;1P(`"+..C-W?__2(GI
M2(G:3(GF2(G'Z*S>__](BX0D"`0``&1(,P0E*````'4W2('$&`0``%M=05Q!
M7<,/'P"%TG6D#Q]``$B+!6EP(`"+..B"W?__3(GJ3(GF2(G'Z$3=___KMN@E
MW?__#Q\`9BX/'X0``````$B#[`A(BP4U<"``BSCH3MW__TB+%?=O(`!(C0TP
M&P``2(TU(AD``$B)QTB#Q`CIM=W__P\?`&8N#Q^$``````!32(L=^&\@`(L[
MZ!'=__](B<?HJ?___XL[Z`+=__];3(T%EQH``$B-%>,3``!(C37Q&```13')
M2(G'3(G!Z:;=__\/'T``9BX/'X0``````#'`PP\?`&8N#Q^$``````!!5T%6
M055!5$F)]%532(G[2(T]Q1@``$B!["@$``!D2(L$)2@```!(B80D&`0``#'`
M2(UT)`SHE?C__[XO````2(G?2(G%Z,7;__](A<!T/4B-/8X8``!(B=XQP.B_
M^?__2(G82(N,)!@$``!D2#,,)2@````/A8P!``!(@<0H!```6UU!7$%=05Y!
M7\-(B=_H@]O__TB--588``!,B>=!B<?HR=O__TB%P$F)Q'2A08/'`4&`/"0`
M3(TU,Q@``$R-;"00#X3G````9@\?1```2(7M=!-,B>9(B>_H0-S__X7`#X2H
M````3(GGZ"C;__^)PDB808!\!/\O=1</'T``@^H!2&/"08!\!/\O0<8$!`!T
M[40!^H'Z_P,```^/+O___TB#[`A(C0WF&```3(T-P!<``%--B>"Z``0``+X!
M````3(GO,<#HI-S__TR+)4UN(`!!BSPDZ&3;__](C9#X`0``3(GNOP,```#H
M6-O__X7`6EEU&D&+/"3H0=O__P^W@`@"``!F)0#P9CT`@'1*,?],B?;HUMK_
M_TB%P$F)Q`^$JO[__T&`/"0`#X4?____2(7M=!-(C3T=%P``N0(```!(B>[S
MIG3'3(TE"A<``+H!````Z3G___^^`0```$R)[^AQVO__A<!UI4B-/?,6``!,
MB>[H)OC__TR)[^@^VO__Z5W^___H;-K__P\?0``/M@](B?B$R7082(U7`6:0
M@/DO#[8*2`]$PDB#P@&$R77N\\-FD&8N#Q^$``````!54TB#[`A(A?]T50^V
M+TB)^T"$[71*Z+W9__](C50#_T@YTW(4ZR=F#Q^$``````!(@^H!2#G3=!^`
M.B]T\NL%@#HO=$!(@^H!2#G3<O)(.=-U,@\?1```0(#]+W5S9I"_`@```.@V
MV___2(7`=%FZ+@```&:)$$B#Q`A;7<-FD(`Z+W4)2(/J`4@YTW+R2"G:2(U"
M`D@]``0``'<K2(T]S&X@`$B)WDB#P@&Y``0``.B#VO__2(/$"$B-!;!N(`!;
M7<,/'T0``$B#Q`@QP%M=PTB#Q`A(C3W8%0``6UWI'=G__P\?`&8N#Q^$````
M``!32(T]OA4``$B#[$!D2(L$)2@```!(B40D.#'`2(L%-1<``$B-7"0,2(E$
M)!!(BP4L%P``2(E$)!A(BP4H%P``2(E$)"!(BP4D%P``2(E$)"@/MP4@%P``
M9HE$)#`QP.C\]?__2(T]9!4``#'`Z.[U__](C3U>%0``,<#HX/7__TB-/5D5
M```QP.C2]?__2(T]4A4``#'`Z,3U__](C3U4%0``,<#HMO7__TB-/?L4```Q
MP.BH]?__2(T]1!4``#'`Z)KU__](C3U`%0``,<#HC/7__TB-/3P5```QP.A^
M]?__2(T]S!0``#'`Z'#U__](C3TJ%0``,<#H8O7__TB-/245```QP.A4]?__
M2(T](A4``#'`2(G>Z(/T__](A<!T$4B-/>04``!(B<8QP.B]]?__2(T]#!4`
M`#'`2(G>Z%ST__](A<!T$4B-/0@5``!(B<8QP.B6]?__2(T]`A4``#'`2(G>
MZ#7T__](A<!T0$B-/344``!(B<8QP.AO]?__2(TU!Q4``$B-/5@4```QP.A:
M]?__2(M$)#AD2#,$)2@```!U9TB#Q$!;PP\?0`!(C3V\%```,<!(B=[HW_/_
M_TB%P'0:2(T]-A0``$B)QC'`Z!GU___KJ`\?@`````!(C70D(4B-/9@4``"Y
M"@```/.F=8Q(C70D*TB-/0(4```QP.CH]/__Z73____H-M?__P\?0`!F+@\?
MA```````2(/L&&1(BP0E*````$B)1"0(,<"+!19L(`"#^/]T&4B+3"0(9$@S
M#"4H````=45(@\08PP\?0`!(C70D!$B-/9\3```QP.@U\___2(7`="`/MA"`
M^C`/E<"$T@^5PB'0#[;`B07':R``Z[0/'T0``#'`Z^SHK];__P\?@`````!(
M@^P(Z'?7__^)Q^A(U___2(7`=`M(BP!(@\0(PP\?`#'`Z_1FD&8N#Q^$````
M``!!5T%6055!5$F)_5532(TMMQ,``$B-':83``!(@^QH9$B+!"4H````2(E$
M)%@QP$B-!9@3``!(B6PD($B)7"0H2,=$)%``````3(UD)"!,C70D'$B)1"0P
M2(T%91,``$B)1"0X2(T%7A,``$B)1"1`2(T%9!,``$B)1"1(ZR!FD$B)Q^B(
MUO__2(7`=&M)@\0(2(7;=#A(B=U)BUPD"$R)]C'`2(GOZ"7R__](A<!)B<=,
MB>YT!8`X`'7%,<!(B>])@\0(Z%?S__](A=MUR$B+1"189$@S!"4H````#X6%
M````2(/$:%M=05Q!74%>05_##Q^``````$R)[^@8U?__3(G_2(E$)`CH"]7_
M_TB+3"0(2(U\`0+HQ-;__TB#[`A,C0W+$0``2(T-Y1(``$%72,?"_____TB)
MQTV)Z+X!````2(E$)!@QP.BBUO__3(M4)!A(B>\QP$R)UNC`\O__6%KI)O__
M_^@,U?__#Q]``$%7059)B?Y!54%42(T]6A$``%532('LB($``&1(BP0E*```
M`$B)A"1X@0``,<!(C05-$@``3(UL)"Q(QT0D0`````!(QX0DF`````````!(
MQT0D8`````!(B40D,$B-!081``!,B>Y(B40D.$B-!:41``!(B40D<$B-!9(1
M``!(B40D>$B-!?P1``!(B80D@````$B-!901``!(B80DB````$B-!>81``!(
MB80DD````$B-!;X1``!(B40D4$B-!<\1``!(B40D6#'`Z)#P__](A<!T"8`X
M``^%4@0``#'`Z'O]__](A<!(B<,/A%\$``!(B=_HK]/__TB-?``!Z&W5__^`
M.P!)B<1T-TR-/8H1``!,B>4/'P!$#[8#2(GO,<!,B?E(Q\+_____O@$```!(
M@\,!2(/%`NA#U?__@#L`==9(C6PD<$B-/<H0``#K#4B#Q0A(BWT`2(7_=#,Q
MP$R)[NCY[___2(7`2(G#=.&`.`!TW$B)Q^@$]?__A<!TT$B)W^A(T___2(7`
M28G'=5!(BUPD,#'MZQL/'X``````@\4!2&/%2(M<Q#!(A=L/A%0!``"`.P`/
MA$L!``!(B=_HN_3__X7`=-=(B=_H_]+__TB%P$F)QW3'#Q^``````$R)_^C`
MTO__3(GABS%(@\$$C9;__O[^]]8A\H'B@("`@'3HB=;![A#WPH"````/1-9(
MC7$"2`]$SHG60`#62(/9`TPIX8V<"`0$``!(8]M(B=_H.=3__TB)Q4B-!6D0
M``!!5$R-#3H/``!(C0U0$```38GX4$C'PO____^^`0```$B)[S'`Z!74__^^
MP`$``$B)[^A0TO__@_C_05A!60^$BP```$R+/:1E(`!!BS_HO-+__TB-D/@!
M``!(B>Z_`P```.BXTO__A<!!B<0/A)T```!(BP7^9B``28L.2(T5S!```$F)
MZ+X!````,=M(BS@QP.B0T___2(N,)'B!``!D2#,,)2@```!(B=@/A3T)``!(
M@<2(@0``6UU!7$%=05Y!7\,/'T``13'_Z=#^___HJ]'__T2+"$&#^1$/A&/_
M__](BP6/9B``28L.2(T5'1```$F)Z+X!````,=M(BS@QP.@AT___ZX\/'X``
M````08L_Z/C1__\/MX`(`@``9B4`\&8]`$`/A4;___]!BS_HV]'__XN`$`(`
M`(D$).A=TO__.00D#X4G____08L_Z+S1__\/MX`(`@``9B7_`68]P`$/A0K_
M__](B=_HO]+__TB-/9P.``!(B<-,B>XQP.B;[?__2(7`#X3J`0``2(G'Z/K0
M__])BSY(B<;HK_3__TB%P$F)Q0^$RP$``$R)[^BST/__@_@#?C9(8]!(C3VK
M#@``N04```!)C705_/.F=1Z#^`0/A,$&``"#Z`1(F$&`?`7_+P^$L`8```\?
M0``QP.BI^?__A<!U%3'V3(GOZ'/0__^%P(D$)`^%<`$``$B--?@-``!(C3UE
M#0``3(TMB`X``#'`3(TU%@T``.@][O__Z-C1__]!54R-#0,-``!02(T-/PX`
M`$C'PO____])B>B^`0```$B)WS'`Z-[1__]86NM-9BX/'X0``````.@+T/__
M@S@1=4OHD='__T&#Q`%(@^P(2(T-"`X``$%5051-B?%028GH2,?"_____[X!
M````2(G?,<#HD='__TB#Q""^P`$``$B)W^C(S___@_C_=*M(B>_HZ]#__TB-
M/5@,``!(B=XQP.B2[?__2(G?Z&KY___IK?W__P\?1```2(G'2(D$).A4^?__
M2(L$)$B)Q^B(S___2(G#Z8C]__^]`0```$B-/1H-``#K$F:02&/%@\4!2(M\
MQ%!(A?]T*3'`3(GNZ.;K__](A<!TX8`X`'3<2(G'Z$3/__](A<!(B<-TS.E8
M^___OPT```!(C1W6#```Z,;0__])B<3I6?O__V8/'T0``$V++NDM_O__3(VT
M)'`!``"Z`@```$C'QN[___]!B<>)Q^B"T/__N@8```!,B?9$B?_HXL___X"\
M)'`!````=0Z`O"1Q`0``0P^$EP4``(L\)#'2,?9,C:PDH````.A&T/__N(FK
MS>](QX0DH`````$C16=(QX0DN````'94,A!(B80DJ````+C^W+J82,>$),@`
M````````2(F$)+````"X\.'2PTC'A"30`````````$B)A"3`````28U%.,>$
M)!@!````````2(E$)!`/'P"+/"2Z`(```$R)]N@XS___A<!)B<1!B<`/CJL!
M``!(B[0DR````$ECQ(T4QD@YU@^'@P$``$B+M"30````2,'H'4B)E"3(````
M2`'P2(F$)-````!(8X0D&`$``(7`#X1$`0``0;A`````2(M4)!!,B?9!*<!%
M.<1%#T[$2(T\`DECR$B)RDF)STB)3"0(Z'7.__^+A"08`0``1`'X@_A`B80D
M&`$```^%4____T6)X$R)[T4I^$R+?"0(1(E$)!SHP]+__T2+1"0<30'W#Q\`
M08/X/P^.G0```$&-0,")1"0<P>@&08G$B40D"$F#Q`%)P>0&30'\D$F+!TR)
M[TF#QT!(B80DV````$F+1\A(B80DX````$F+1]!(B80DZ````$F+1]A(B80D
M\````$F+1^!(B80D^````$F+1^A(B80D``$``$F+1_!(B80D"`$``$F+1_A(
MB80D$`$``.@ETO__33G\=9"+1"0(1(M$)!S!X`9!*<!(BWPD$$ECT+E(````
M3(G^1(E$)`CH5\W__T2+1"0(1(F$)!@!``#I7?[__P\?1```38GWZ2#___\/
M'X0``````$B+C"30````2(UQ`>ET_O__BSPDZ"?-__],BZ0DR````$R+M"30
M````3(G@2,'H`X/@/XU0`4B8QH0$V````("#^C@/CXX"``"X.````"G02&/2
M@_@(28U4%3@/@[8"``"H!`^%9P,``(7`=`NH`L8"``^%:P,``$R)\$R)[T2(
MM"03`0``2,'H&$2(I"07`0``3(V\)"$!``"(A"00`0``3(GP3(TML0D``$C!
MZ!"(A"01`0``3(GP3(VT)&@!``!(P>@(B(0D$@$``$R)X$C!Z!B(A"04`0``
M3(G@2,'H$(B$)!4!``!,B>!(P>@(B(0D%@$``.C5T/__2(N$)*````!(B<*(
MA"0C`0``2,'J&$0/ML*(E"0@`0``2(G"2,'J$(B4)"$!``!(B<)(BX0DJ```
M`$C!Z@B(E"0B`0``2(G"B(0D)P$``$C!ZAB(E"0D`0``2(G"2,'J$(B4)"4!
M``!(B<)(BX0DL````$C!Z@B(E"0F`0``2(G"B(0D*P$``$C!ZAB(E"0H`0``
M2(G"2,'J$(B4)"D!``!(B<)(BX0DN````$C!Z@B(E"0J`0``2(G"B(0D+P$`
M`$C!ZAB(E"0L`0``2(G"2,'J$(B4)"T!``!(B<)(BX0DP````$C!Z@B(E"0N
M`0``2(G"B(0D,P$``$C!ZAB(E"0P`0``2(G"2,'J$(B4)#$!``!(B<)(C80D
M0`$``$C!Z@B(E"0R`0``2(D$)$F)Q.D(````10^V!TF#QP%,B><QP$R)Z4C'
MPO____^^`0```$F#Q`+HZ\O__TTYYG762(T%3`@``,:$)&@!````4/]T)`A(
MC0T$"```3(T-R`8``+X!````28GH2,?"_____TB)WS'`Z*O+__]97NDI^O__
M38MV"$V%]@^$1_G__TR)]^BWR?__2(/X`P^&-?G__TF-=`;\2(T]K0<``+D%
M````\Z9-#T3NZ1GY__^X0````$ACRBG028U,#3B)PG0/,<")QH/``3G0Q@0Q
M`'+S3(GOZ,_.__])C54XN0<````QP$B)U_-(J^EA_?__B<%(QP(`````2,=$
M"O@`````2(U*"$B#X?A(*<H!T(/@^(/X"`^"-OW__X/@^#'2B=:#P@@YPDC'
M!#$`````<N_I&_W__X"\)'(!``!!#X5;^O__@+PD<P$``$,/A4WZ__^`O"1T
M`0``2`^%/_K__X"\)'4!``!%#X4Q^O__1(L\)+H"````2,?&QO___T2)_^AS
MRO__NBD```!,B?9$B?_HT\G__TB-!>D&``!005;IHO[__P\?0`#'`@````#'
M1`+\`````.F5_/__,?]FB7P"_NF)_/__Z-3(__]FD&8N#Q^$``````!!5T%6
M055!5%532(/L&$R+)=M;(`!D2(L$)2@```!(B40D"#'`3(UT)`1!BSPDZ-W(
M__]!BSPD2(G#Z-'(__\/MH"P````2(T]&@4``$R)]HB#L0```#'`Z,/D__](
MA<!T"8`X,0^$G0(``#'`Z`[O__]!BSPDZ)7(__](C34E!@``N0L```"Z`0``
M`$B)Q^B4R/__2(7`#X2T````@SUL82```4B+0!!,BV@H#XZ?````,>V[`0``
M`.LP#Q]$``!)BW<02(L%/6$@`$ACTTB+/-#HF<C__X7`=66+!2]A(`"#PP&#
MQ0$YV'Y;08L\).@<R/__,<E(8]5,B>Y(B<?HY,C__TB%P'0W3(LX08M'#"4`
M!"``/0`$``!TI$&+/"3HZ\?__TR)_KD"````,=)(B<?HL<?__TB)QNN(#Q]`
M`(L%RF`@`(U0_SGJ#X1W`0``08L\).BVQ___2(TU2P4``+D#````N@$```!(
MB<?HM<?__TB%P$B)PW0S2(M`$$&+/"1(BRCHA<?__TB-%1P%``!(B<=(B>[H
M0\?__TB+0Q!(BQCV0PY`#X7,`0``08L\).A9Q___2(TU]0,``+D#````N@$`
M``!(B<?H6,?__TB%P$B)PW0[2(T]5@,``#'`3(GVZ#?C__](A<!(B<4/A%L!
M``!(BT,008L\)$B+&.@+Q___2(GJ2(G'2(G>Z,W&__]!BSPDZ/3&__](C360
M!```N@$```!(B<?H4,?__T&+/"1(B</HU,;__TB-%84$``!(B=Y(B<?HDL;_
M_T&+/"3HN<;__TB-/<X"``#&@+$`````3(GV,<#HL>+__TB%P$B)PTB)!9Q?
M(``/A)X```"^P`$``$B)W^CYQ?__C5`!@_H!=@F#^!$/A?@```!(BT0D"&1(
M,P0E*`````^%WP```$B#Q!A;74%<05U!7D%?PP\?1```@_@!#XZ`_O__NP$`
M``!F+@\?A```````08L\)(/#`>@DQO__3(GN2(G'Z*G%__\Y'1-?(`!_X>E-
M_O__#Q]``(!X`0`/A&#]___I5/W__V8/'X0``````$B+/>%>(`#HE/#__TB%
MP$B)PTB)!=]>(``/A4/___](C3UB!```,<#H.\;__P\?`$B+!;%>(`!!BSPD
M2(LH2(M#$$B+&.BFQ?__2(GN2(G?Z%OG___IF?[__T&+/"3HC<7__TB)WDB)
MQ^@RQO__Z1O^___H,,7__XG!2(L%9UX@`$B-/2@$``!(B=I(BS`QP.C3Q?__
MD&8N#Q^$``````!54TB)_4B#[`CHPNK__P^V"(3)=$Y(C5`!2(G##Q]``(#Y
M+P^V"D@/1-I(@\(!A,EU[C'`Z*?M__](A>UT'H7`=!J`?0``=!1(C35;`@``
M2(G?Z$G%__](.=AT#$B#Q`A;7<-(B</KRDB#Q`A(B>];7>F*Y/__9BX/'X0`
M`````$B-!8%9(`!(A<!T#$B+".FLQ/__#Q]``#')Z:'$__^005=!5D&)_T%5
M051,C26^5"``54B-+;Y4(`!328GV28G53"GE2(/L"$C!_0/HI\/__TB%[70@
M,=L/'X0``````$R)ZDR)]D2)_T'_%-Q(@\,!2#G==>I(@\0(6UU!7$%=05Y!
M7\.09BX/'X0``````//#``!(@^P(2(/$",,````!``(`)7,O)7,`+W!R;V,O
M<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),
M-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%2
M7T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`
M4TA,24)?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).
M04U%`"4P,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#,U`"UE`"TM``````!?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````<&5R;'AS:2YC````
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S
M:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^
M9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM
M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F
M)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T
M;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?
M,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[
M(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P
M(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I
M('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X
M(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T
M(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E
M:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A
M9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B
M)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED
M>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@
M/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q
M,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD
M;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E
M860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H
M)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@
M*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S
M92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO
M)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO
M<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D
M92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F
M:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP
M<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E
M;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@
M;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H
M9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R
M."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO
M="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2([
M"GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II
M<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z
M)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>
M.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P
M87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL
M92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H
M*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H
M*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N
M9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(
M/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L
M("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I
M9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@
M+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*
M?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X[
M"F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL
M92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]
M"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE
M+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E
M<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R
M968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]
M*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI
M8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY
M("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I
M92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N
M=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M
M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E
M,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I
M+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I
M;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H
M95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC
M:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE
M.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]
M+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD
M"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E
M<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M
M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E
M<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*
M)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64[
M"G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU
M;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F
M:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E
M='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA
M;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```````$;`SO<````
M&@```+B"__\H`0``N(3__U`&``#]AO__^````#B(__]0`0``B)___Z`!``!(
MH/__\`$``-B@__\@`@``**/__W`"``"HI/__N`(``#BE___P`@``&*;__S`#
M``!8IO__2`,``*BF__]H`P``N*;__X`#``#(J/__X`,``/BH___X`P``Z*G_
M_T@$```(K/__<`0``(BL__^0!```N*S__[`$```HKO__$`4``&BZ___(!0``
M*+[__Q@&``"HOO__@`8``,B^__^8!@``.+___^`&````````%``````````!
M>E(``7@0`1L,!PB0`0<0%````!P```#]A?__-```````````````%```````
M```!>E(``7@0`1L,!PB0`0``)````!P```"(@?__$``````.$$8.&$H/"W<(
M@``_&CLJ,R0B`````$P```!$````X(;__T87````0@X0CP)"#AB.`T8.((T$
M0@XHC`5##C"&!D$..(,'1P[0!0,?%PH..$$.,$$.*$(.($(.&$(.$$(."$$+
M````3````)0```#@G?__O@````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P=$#D`"?`H..$0.,$$.*$(.($(.&$(.$$(."$D+```````L````Y```
M`%">__^&`````$$.$(8"00X8@P-'#C`"=0H.&$$.$$$."$$+``````!,````
M%`$``+">__].`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!TH.
M8`,>`0H..$$.,$$.*$(.($(.&$(.$$(."$0+`````$0```!D`0``L*#__WP!
M````0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.P`%^"@XP00XH00X@0@X8
M0@X00@X(2PL``````#0```"L`0``Z*'__XP`````00X0A@)!#AB#`T<.(&H*
M#AA##A!!#@A)"P)&#AA$#A!!#@@`````/````.0!``!`HO__TP````!"#A"-
M`D(.&(P#1`X@A@1!#BB#!58.P`@"?PH.*$$.($$.&$(.$$(."$0+`````!0`
M```D`@``X*+__S,`````1`X0:@X(`!P````\`@``"*/__T(`````00X0@P)>
M#@@`````````%````%P"```XH___`P``````````````7````'0"```PH___
M#`(```!"#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&00XX@P=1#N`(`F0*#CA!
M#C!!#BA"#B!"#AA"#A!"#@A!"P*9#N@(3P[P"'X.Z`A!#N`(````%````-0"
M``#@I/__)```````````````3````.P"``#XI/__XP````!!#A"&`D$.&(,#
M1`X@`G4*#AA!#A!!#@A#"WD*#AA(#A!!#@A&"T0*#AA##A!!#@A!"T0.&$@.
M$$$."``````D````/`,``)BE__\2`@```$$.$(,"2PY0`YX!"@X000X(10L`
M````'````&0#``"0I___>0````!$#B!O"@X(10L````````<````A`,``/"G
M__\D`````$0.$%@*#@A$"P```````%P```"D`P```*C__VP!````0@X0CP)"
M#AB.`T(.((T$0@XHC`5$#C"&!D$..(,'4@Z@`0+'"@XX00XP00XH0@X@0@X8
M0@X00@X(2`MH#J@!4`ZP`7$.J`%!#J`!`````+0````$!```$*G__S0,````
M0@X0CP)"#AB.`T4.((T$0@XHC`5(#C"&!D$..(,'1P[`@P(#*`(.R(,"4@[0
M@P)H#LB#`D(.P(,"`GH*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"P-R`0[(@P)(
M#M"#`F$.R(,"00[`@P)C#LB#`DD.T(,"0@[8@P)$#N"#`ET.P(,"`[<%#LB#
M`D0.T(,":`[(@P)!#L"#`@,N`0H.R(,"0@[0@P))"P!,````O`0``)BT__^U
M`P```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.4`.J`@H..$$.
M,$$.*$(.($(.&$(.$$(."$8+`````#0````,!0``"+C__W8`````00X0A@)!
M#AB#`T<.(`)7"@X800X000X(00M)#AA$#A!!#@@`````+````$0%``!@?O__
M10(```!!#A"&`D$.&(,#1`Y0`Y0!"@X800X000X(00L`````%````'0%```@
MN/__'P``````````````1````(P%```HN/__90````!"#A"/`D(.&(X#10X@
MC01"#BB,!4@.,(8&2`XX@P=-#D!R#CA!#C!!#BA"#B!"#AA"#A!"#@@`%```
M`-0%``!0N/__`@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````.`?````````H!\```````````````````$`````````
M`0`````````!`````````.0!`````````0````````#O`0````````$`````
M````^0$````````!`````````$@"`````````0````````"8`P````````P`
M````````>!H````````-`````````!17````````&0````````!PJR``````
M`!L`````````"``````````:`````````'BK(```````'``````````(````
M`````/7^_V\`````H`(````````%`````````/`,````````!@````````!X
M`P````````H`````````[`0````````+`````````!@`````````%0``````
M``````````````,`````````F*T@```````'`````````"@3````````"```
M``````!0!P````````D`````````&``````````8````````````````````
M^___;P`````!```(`````/[__V\`````J!(```````#___]O``````(`````
M````\/__;P````#<$0```````/G__V\`````!0``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(BK(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````:+0@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````!86@```````$=#
M0SH@*$1E8FEA;B`V+C(N,"TT*2`V+C(N,"`R,#$V,#DQ-`!'0T,Z("A$96)I
M86X@-BXR+C`M,BD@-BXR+C`@,C`Q-C`X,S```"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96QA+F1Y;@`N:6YI=``N<&QT`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+FIC<@`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0````(`````````.`(````````X`@``````
M`!T````````````````````!````````````````````$P````<````"````
M`````%@"````````6`(````````@````````````````````!```````````
M`````````"$````'`````@````````!X`@```````'@"````````)```````
M``````````````0````````````````````T````]O__;P(`````````H`(`
M``````"@`@```````-@`````````!0`````````(````````````````````
M/@````L````"`````````'@#````````>`,```````!X"0````````8````!
M````"``````````8`````````$8````#`````@````````#P#````````/`,
M````````[`0```````````````````$```````````````````!.````____
M;P(`````````W!$```````#<$0```````,H`````````!0`````````"````
M``````(`````````6P```/[__V\"`````````*@2````````J!(```````"`
M``````````8````"````"````````````````````&H````$`````@``````
M```H$P```````"@3````````4`<````````%``````````@`````````&```
M``````!T`````0````8`````````>!H```````!X&@```````!<`````````
M```````````$````````````````````>@````$````&`````````)`:````
M````D!H````````0````````````````````$``````````0`````````'\`
M```!````!@````````"@&@```````*`:````````Z`$`````````````````
M``@```````````````````"(`````0````8`````````D!P```````"0'```
M`````((Z```````````````````0````````````````````C@````$````&
M`````````!17````````%%<````````)````````````````````!```````
M`````````````)0````!`````@`````````@5P```````"!7````````N$``
M``````````````````@```````````````````"<`````0````(`````````
MV)<```````#8EP```````-P````````````````````$````````````````
M````J@````$````"`````````+B8````````N)@````````<!@``````````
M````````"````````````````````+0````.`````P````````!PJR``````
M`'"K````````"`````````````````````@`````````"`````````#`````
M#P````,`````````>*L@``````!XJP````````@````````````````````(
M``````````@`````````S`````$````#`````````("K(```````@*L`````
M```(````````````````````"````````````````````-$````&`````P``
M``````"(JR```````(BK````````$`(````````&``````````@`````````
M$`````````"#`````0````,`````````F*T@``````"8K0```````&@"````
M```````````````(``````````@`````````V@````$````#``````````"P
M(````````+`````````@````````````````````"```````````````````
M`.`````(`````P`````````@L"```````""P````````2`0`````````````
M`````"````````````````````#E`````0```#`````````````````````@
ML````````$H````````````````````!``````````$``````````0````,`
M````````````````````````:K````````#N`````````````````````0``
-````````````````````
